"""ens_probe module

The ens_probe module provides a proxy interface to EnSight ENS_PROBE instances

"""
from ansys.pyensight.core.session import Session
from ansys.pyensight.core.ensobj import ENSOBJ
from ansys.pyensight.core import ensobjlist
from typing import Any, Dict, List, Type, Union, Optional, Tuple, TYPE_CHECKING, cast

if TYPE_CHECKING:
    from ansys.api.pyensight.ensight_api import ENS_VAR, ENS_ANNOT, ENS_PALETTE, ENS_PART, ENS_SOURCE, ENS_CASE, ENS_QUERY, ENS_GROUP, ENS_TOOL, ENS_TEXTURE, ENS_VPORT, ENS_PLOTTER, ENS_POLYLINE, ENS_FRAME, ENS_FLIPBOOK, ENS_SCENE, ENS_LPART, ENS_STATE, ens_emitterobj

class ENS_PROBE(ENSOBJ):
    """This class acts as a proxy for the EnSight Python class ensight.objs.ENS_PROBE

    Args:
        \*args:
            Superclass (ENSOBJ) arguments
        \**kwargs:
            Superclass (ENSOBJ) keyword arguments

    """

    def __init__(self, *args, **kwargs) -> None:
        super().__init__(*args, **kwargs)
        self._update_attr_list(self._session, self._objid)

    @classmethod
    def _update_attr_list(cls, session: 'Session', id: int) -> None:
        if hasattr(cls, 'attr_list'):
            return
        cmd = session.remote_obj(id) + '.__ids__'
        cls.attr_list = session.cmd(cmd)

    @property
    def objid(self) -> int:  # noqa: N802
        """
        Return the EnSight object proxy ID (__OBJID__).
        """
        return self._objid

    def remove(self, *args, **kwargs) -> Any:
        """Remove one probe

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.remove({arg_string})"
        return self._session.cmd(cmd)

    def surface_pick(self, *args, **kwargs) -> Any:
        """Pick at given mouse position

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.surface_pick({arg_string})"
        return self._session.cmd(cmd)

    def attrgroupinfo(self, *args, **kwargs) -> Any:
        """Get information about GUI groups for this probe's attributes

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.attrgroupinfo({arg_string})"
        return self._session.cmd(cmd)

    @property
    def METADATA(self) -> Dict[Any, Any]:
        """METADATA property
        
        metadata
        
        Supported operations:
            getattr
        Datatype:
            CEI Metadata, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.METADATA)
        _value = cast(Dict[Any, Any], value)
        return _value

    @property
    def metadata(self) -> Dict[Any, Any]:
        """METADATA property
        
        metadata
        
        Supported operations:
            getattr
        Datatype:
            CEI Metadata, scalar
        
        Note: both 'metadata' and 'METADATA' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.METADATA)
        _value = cast(Dict[Any, Any], value)
        return _value

    @property
    def UUID(self) -> str:
        """UUID property
        
        universal unique id
        
        Supported operations:
            getattr
        Datatype:
            String, 37 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.UUID)
        _value = cast(str, value)
        return _value

    @property
    def uuid(self) -> str:
        """UUID property
        
        universal unique id
        
        Supported operations:
            getattr
        Datatype:
            String, 37 characters maximum
        
        Note: both 'uuid' and 'UUID' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.UUID)
        _value = cast(str, value)
        return _value

    @property
    def EDIT_TARGET(self) -> int:
        """EDIT_TARGET property
        
        currently an edit target
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.EDIT_TARGET)
        _value = cast(int, value)
        return _value

    @property
    def edit_target(self) -> int:
        """EDIT_TARGET property
        
        currently an edit target
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        Note: both 'edit_target' and 'EDIT_TARGET' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.EDIT_TARGET)
        _value = cast(int, value)
        return _value

    @property
    def PROJECT_MASK(self) -> int:
        """PROJECT_MASK property
        
        object project mask
        
        Supported operations:
            getattr, setattr
        Datatype:
            64bit integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.PROJECT_MASK)
        _value = cast(int, value)
        return _value

    @PROJECT_MASK.setter
    def PROJECT_MASK(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.PROJECT_MASK, value)

    @property
    def project_mask(self) -> int:
        """PROJECT_MASK property
        
        object project mask
        
        Supported operations:
            getattr, setattr
        Datatype:
            64bit integer, scalar
        
        Note: both 'project_mask' and 'PROJECT_MASK' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.PROJECT_MASK)
        _value = cast(int, value)
        return _value

    @project_mask.setter
    def project_mask(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.PROJECT_MASK, value)

    @property
    def HANDLES_ENABLED(self) -> int:
        """Control the display and use of EnSight click and go handles for an object
        
        EnSight allows for direct interaction with many objects via click and go handles.
        The handles allow things like annotations and viewports to be moved or resized.
        They allow for the adjustment of values for clip planes and palette dynamic ranges.
        In some situations, allowing the user to directly adjust these values can be
        undesirable.  Setting this attribute to zero disables display of and interaction
        with click and go handles for the specific object instance.
        
        """
        value = self.getattr(self._session.ensight.objs.enums.HANDLES_ENABLED)
        _value = cast(int, value)
        return _value

    @HANDLES_ENABLED.setter
    def HANDLES_ENABLED(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.HANDLES_ENABLED, value)

    @property
    def handles_enabled(self) -> int:
        """Control the display and use of EnSight click and go handles for an object
        
        EnSight allows for direct interaction with many objects via click and go handles.
        The handles allow things like annotations and viewports to be moved or resized.
        They allow for the adjustment of values for clip planes and palette dynamic ranges.
        In some situations, allowing the user to directly adjust these values can be
        undesirable.  Setting this attribute to zero disables display of and interaction
        with click and go handles for the specific object instance.
        
        Note: both 'handles_enabled' and 'HANDLES_ENABLED' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.HANDLES_ENABLED)
        _value = cast(int, value)
        return _value

    @handles_enabled.setter
    def handles_enabled(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.HANDLES_ENABLED, value)

    @property
    def VARIABLES(self) -> List[dict]:
        """VARIABLES property
        
        variables
        
        Supported operations:
            getattr, setattr
        Datatype:
            List of dictionaries, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.VARIABLES)
        _value = cast(List[dict], value)
        return _value

    @VARIABLES.setter
    def VARIABLES(self, value: List[dict]) -> None:
        self.setattr(self._session.ensight.objs.enums.VARIABLES, value)

    @property
    def variables(self) -> List[dict]:
        """VARIABLES property
        
        variables
        
        Supported operations:
            getattr, setattr
        Datatype:
            List of dictionaries, scalar
        
        Note: both 'variables' and 'VARIABLES' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.VARIABLES)
        _value = cast(List[dict], value)
        return _value

    @variables.setter
    def variables(self, value: List[dict]) -> None:
        self.setattr(self._session.ensight.objs.enums.VARIABLES, value)

    @property
    def DESCRIPTION(self) -> str:
        """DESCRIPTION property
        
        description
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 256 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.DESCRIPTION)
        _value = cast(str, value)
        return _value

    @DESCRIPTION.setter
    def DESCRIPTION(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.DESCRIPTION, value)

    @property
    def description(self) -> str:
        """DESCRIPTION property
        
        description
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 256 characters maximum
        
        Note: both 'description' and 'DESCRIPTION' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.DESCRIPTION)
        _value = cast(str, value)
        return _value

    @description.setter
    def description(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.DESCRIPTION, value)

    @property
    def PROBE_DATA(self) -> List[dict]:
        """PROBE_DATA property
        
        probe data
        
        Supported operations:
            getattr
        Datatype:
            List of dictionaries, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.PROBE_DATA)
        _value = cast(List[dict], value)
        return _value

    @property
    def probe_data(self) -> List[dict]:
        """PROBE_DATA property
        
        probe data
        
        Supported operations:
            getattr
        Datatype:
            List of dictionaries, scalar
        
        Note: both 'probe_data' and 'PROBE_DATA' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.PROBE_DATA)
        _value = cast(List[dict], value)
        return _value

    @property
    def LABELVISIBLE(self) -> int:
        """LABELVISIBLE property
        
        Label Visible
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LABELVISIBLE)
        _value = cast(int, value)
        return _value

    @LABELVISIBLE.setter
    def LABELVISIBLE(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LABELVISIBLE, value)

    @property
    def labelvisible(self) -> int:
        """LABELVISIBLE property
        
        Label Visible
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'labelvisible' and 'LABELVISIBLE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LABELVISIBLE)
        _value = cast(int, value)
        return _value

    @labelvisible.setter
    def labelvisible(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LABELVISIBLE, value)

    @property
    def LABELRGB(self) -> List[float]:
        """LABELRGB property
        
        Color
        
        Supported operations:
            getattr, setattr
        Datatype:
            Color RGB, 3 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LABELRGB)
        _value = cast(List[float], value)
        return _value

    @LABELRGB.setter
    def LABELRGB(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.LABELRGB, value)

    @property
    def labelrgb(self) -> List[float]:
        """LABELRGB property
        
        Color
        
        Supported operations:
            getattr, setattr
        Datatype:
            Color RGB, 3 element array
        
        Note: both 'labelrgb' and 'LABELRGB' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LABELRGB)
        _value = cast(List[float], value)
        return _value

    @labelrgb.setter
    def labelrgb(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.LABELRGB, value)

    @property
    def LABELFORMAT(self) -> int:
        """LABELFORMAT property
        
        Label format
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.F_FORMAT - floating_point
            * ensight.objs.enums.E_FORMAT - exponential
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LABELFORMAT)
        _value = cast(int, value)
        return _value

    @LABELFORMAT.setter
    def LABELFORMAT(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LABELFORMAT, value)

    @property
    def labelformat(self) -> int:
        """LABELFORMAT property
        
        Label format
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.F_FORMAT - floating_point
            * ensight.objs.enums.E_FORMAT - exponential
        
        Note: both 'labelformat' and 'LABELFORMAT' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LABELFORMAT)
        _value = cast(int, value)
        return _value

    @labelformat.setter
    def labelformat(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LABELFORMAT, value)

    @property
    def LABELDECIMALPLACES(self) -> int:
        """LABELDECIMALPLACES property
        
        Label decimal places
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        Range:
            [0, 6]
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LABELDECIMALPLACES)
        _value = cast(int, value)
        return _value

    @LABELDECIMALPLACES.setter
    def LABELDECIMALPLACES(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LABELDECIMALPLACES, value)

    @property
    def labeldecimalplaces(self) -> int:
        """LABELDECIMALPLACES property
        
        Label decimal places
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        Range:
            [0, 6]
        
        Note: both 'labeldecimalplaces' and 'LABELDECIMALPLACES' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LABELDECIMALPLACES)
        _value = cast(int, value)
        return _value

    @labeldecimalplaces.setter
    def labeldecimalplaces(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LABELDECIMALPLACES, value)

    @property
    def MARKERVISIBLE(self) -> int:
        """MARKERVISIBLE property
        
        Marker visible
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.MARKERVISIBLE)
        _value = cast(int, value)
        return _value

    @MARKERVISIBLE.setter
    def MARKERVISIBLE(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.MARKERVISIBLE, value)

    @property
    def markervisible(self) -> int:
        """MARKERVISIBLE property
        
        Marker visible
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'markervisible' and 'MARKERVISIBLE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.MARKERVISIBLE)
        _value = cast(int, value)
        return _value

    @markervisible.setter
    def markervisible(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.MARKERVISIBLE, value)

    @property
    def MARKERRGB(self) -> List[float]:
        """MARKERRGB property
        
        Marker color
        
        Supported operations:
            getattr, setattr
        Datatype:
            Color RGB, 3 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.MARKERRGB)
        _value = cast(List[float], value)
        return _value

    @MARKERRGB.setter
    def MARKERRGB(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.MARKERRGB, value)

    @property
    def markerrgb(self) -> List[float]:
        """MARKERRGB property
        
        Marker color
        
        Supported operations:
            getattr, setattr
        Datatype:
            Color RGB, 3 element array
        
        Note: both 'markerrgb' and 'MARKERRGB' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.MARKERRGB)
        _value = cast(List[float], value)
        return _value

    @markerrgb.setter
    def markerrgb(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.MARKERRGB, value)

    @property
    def MARKERSIZENORMALIZED(self) -> float:
        """MARKERSIZENORMALIZED property
        
        Marker normalize
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.MARKERSIZENORMALIZED)
        _value = cast(float, value)
        return _value

    @MARKERSIZENORMALIZED.setter
    def MARKERSIZENORMALIZED(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.MARKERSIZENORMALIZED, value)

    @property
    def markersizenormalized(self) -> float:
        """MARKERSIZENORMALIZED property
        
        Marker normalize
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        Note: both 'markersizenormalized' and 'MARKERSIZENORMALIZED' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.MARKERSIZENORMALIZED)
        _value = cast(float, value)
        return _value

    @markersizenormalized.setter
    def markersizenormalized(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.MARKERSIZENORMALIZED, value)

    @property
    def QUERY(self) -> int:
        """QUERY property
        
        Action
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.INT_QUERY_SURFACE - surface
            * ensight.objs.enums.INT_QUERY_POINT - cursor
            * ensight.objs.enums.INT_QUERY_NODEID - node
            * ensight.objs.enums.INT_QUERY_IJK - ijk
            * ensight.objs.enums.INT_QUERY_ELEMID - element
            * ensight.objs.enums.INT_QUERY_XYZ - xyz
            * ensight.objs.enums.INT_QUERY_MIN - min
            * ensight.objs.enums.INT_QUERY_MAX - max
            * ensight.objs.enums.INT_QUERY_NONE - none
        
        """
        value = self.getattr(self._session.ensight.objs.enums.QUERY)
        _value = cast(int, value)
        return _value

    @QUERY.setter
    def QUERY(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.QUERY, value)

    @property
    def query(self) -> int:
        """QUERY property
        
        Action
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.INT_QUERY_SURFACE - surface
            * ensight.objs.enums.INT_QUERY_POINT - cursor
            * ensight.objs.enums.INT_QUERY_NODEID - node
            * ensight.objs.enums.INT_QUERY_IJK - ijk
            * ensight.objs.enums.INT_QUERY_ELEMID - element
            * ensight.objs.enums.INT_QUERY_XYZ - xyz
            * ensight.objs.enums.INT_QUERY_MIN - min
            * ensight.objs.enums.INT_QUERY_MAX - max
            * ensight.objs.enums.INT_QUERY_NONE - none
        
        Note: both 'query' and 'QUERY' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.QUERY)
        _value = cast(int, value)
        return _value

    @query.setter
    def query(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.QUERY, value)

    @property
    def SEARCH(self) -> int:
        """SEARCH property
        
        Search
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.INT_QUERY_EXACT - exact
            * ensight.objs.enums.INT_QUERY_NODE - closest_node
        
        """
        value = self.getattr(self._session.ensight.objs.enums.SEARCH)
        _value = cast(int, value)
        return _value

    @SEARCH.setter
    def SEARCH(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SEARCH, value)

    @property
    def search(self) -> int:
        """SEARCH property
        
        Search
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.INT_QUERY_EXACT - exact
            * ensight.objs.enums.INT_QUERY_NODE - closest_node
        
        Note: both 'search' and 'SEARCH' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.SEARCH)
        _value = cast(int, value)
        return _value

    @search.setter
    def search(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SEARCH, value)

    @property
    def REQUESTMETHOD(self) -> int:
        """REQUESTMETHOD property
        
        Request
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.FALSE - continuous
            * ensight.objs.enums.TRUE - pick
        
        """
        value = self.getattr(self._session.ensight.objs.enums.REQUESTMETHOD)
        _value = cast(int, value)
        return _value

    @REQUESTMETHOD.setter
    def REQUESTMETHOD(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.REQUESTMETHOD, value)

    @property
    def requestmethod(self) -> int:
        """REQUESTMETHOD property
        
        Request
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.FALSE - continuous
            * ensight.objs.enums.TRUE - pick
        
        Note: both 'requestmethod' and 'REQUESTMETHOD' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.REQUESTMETHOD)
        _value = cast(int, value)
        return _value

    @requestmethod.setter
    def requestmethod(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.REQUESTMETHOD, value)

    @property
    def LABELALWAYSONTOP(self) -> int:
        """LABELALWAYSONTOP property
        
        Always on top
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LABELALWAYSONTOP)
        _value = cast(int, value)
        return _value

    @LABELALWAYSONTOP.setter
    def LABELALWAYSONTOP(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LABELALWAYSONTOP, value)

    @property
    def labelalwaysontop(self) -> int:
        """LABELALWAYSONTOP property
        
        Always on top
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'labelalwaysontop' and 'LABELALWAYSONTOP' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LABELALWAYSONTOP)
        _value = cast(int, value)
        return _value

    @labelalwaysontop.setter
    def labelalwaysontop(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LABELALWAYSONTOP, value)

    @property
    def NUMDISPLAYED(self) -> int:
        """NUMDISPLAYED property
        
        Marker number
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        Range:
            [0, inf]
        
        """
        value = self.getattr(self._session.ensight.objs.enums.NUMDISPLAYED)
        _value = cast(int, value)
        return _value

    @NUMDISPLAYED.setter
    def NUMDISPLAYED(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.NUMDISPLAYED, value)

    @property
    def numdisplayed(self) -> int:
        """NUMDISPLAYED property
        
        Marker number
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        Range:
            [0, inf]
        
        Note: both 'numdisplayed' and 'NUMDISPLAYED' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.NUMDISPLAYED)
        _value = cast(int, value)
        return _value

    @numdisplayed.setter
    def numdisplayed(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.NUMDISPLAYED, value)



"""ens_group module

The ens_group module provides a proxy interface to EnSight ENS_GROUP instances

"""
from ansys.pyensight.core.session import Session
from ansys.pyensight.core.ensobj import ENSOBJ
from ansys.pyensight.core import ensobjlist
from typing import Any, Dict, List, Type, Union, Optional, Tuple, TYPE_CHECKING, cast

if TYPE_CHECKING:
    from ansys.api.pyensight.ensight_api import ENS_VAR, ENS_ANNOT, ENS_PALETTE, ENS_PART, ENS_SOURCE, ENS_CASE, ENS_QUERY, ENS_TOOL, ENS_TEXTURE, ENS_VPORT, ENS_PLOTTER, ENS_POLYLINE, ENS_FRAME, ENS_PROBE, ENS_FLIPBOOK, ENS_SCENE, ENS_LPART, ENS_STATE, ens_emitterobj

class ENS_GROUP(ENSOBJ):
    """This class acts as a proxy for the EnSight Python class ensight.objs.ENS_GROUP

    Args:
        \*args:
            Superclass (ENSOBJ) arguments
        \**kwargs:
            Superclass (ENSOBJ) keyword arguments

    """

    def __init__(self, *args, **kwargs) -> None:
        super().__init__(*args, **kwargs)
        self._update_attr_list(self._session, self._objid)

    @classmethod
    def _update_attr_list(cls, session: 'Session', id: int) -> None:
        if hasattr(cls, 'attr_list'):
            return
        cmd = session.remote_obj(id) + '.__ids__'
        cls.attr_list = session.cmd(cmd)

    @property
    def objid(self) -> int:  # noqa: N802
        """
        Return the EnSight object proxy ID (__OBJID__).
        """
        return self._objid

    def addchild(self, *args, **kwargs) -> Any:
        """Add a child to an object

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.addchild({arg_string})"
        return self._session.cmd(cmd)

    def setchildattr(self, *args, **kwargs) -> Any:
        """Set attribute on object children

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.setchildattr({arg_string})"
        return self._session.cmd(cmd)

    def setchildattrs(self, *args, **kwargs) -> Any:
        """Set attributes on object children

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.setchildattrs({arg_string})"
        return self._session.cmd(cmd)

    def attrgroupinfo(self, *args, **kwargs) -> Any:
        """Get information about GUI groups for object attributes

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.attrgroupinfo({arg_string})"
        return self._session.cmd(cmd)

    def removechild(self, *args, **kwargs) -> Any:
        """Remove child from this group

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.removechild({arg_string})"
        return self._session.cmd(cmd)

    def refreshgui(self, *args, **kwargs) -> Any:
        """Refresh the selection GUI

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.refreshgui({arg_string})"
        return self._session.cmd(cmd)

    def creategroup(self, *args, **kwargs) -> Any:
        """Create a group (ENS_GROUP) child

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.creategroup({arg_string})"
        return self._session.cmd(cmd)

    def transform(self, *args, **kwargs) -> Any:
        """Apply an incremental transform

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.transform({arg_string})"
        return self._session.cmd(cmd)

    @property
    def METADATA(self) -> Dict[Any, Any]:
        """METADATA property
        
        metadata
        
        Supported operations:
            getattr
        Datatype:
            CEI Metadata, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.METADATA)
        _value = cast(Dict[Any, Any], value)
        return _value

    @property
    def metadata(self) -> Dict[Any, Any]:
        """METADATA property
        
        metadata
        
        Supported operations:
            getattr
        Datatype:
            CEI Metadata, scalar
        
        Note: both 'metadata' and 'METADATA' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.METADATA)
        _value = cast(Dict[Any, Any], value)
        return _value

    @property
    def UUID(self) -> str:
        """UUID property
        
        universal unique id
        
        Supported operations:
            getattr
        Datatype:
            String, 37 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.UUID)
        _value = cast(str, value)
        return _value

    @property
    def uuid(self) -> str:
        """UUID property
        
        universal unique id
        
        Supported operations:
            getattr
        Datatype:
            String, 37 characters maximum
        
        Note: both 'uuid' and 'UUID' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.UUID)
        _value = cast(str, value)
        return _value

    @property
    def EDIT_TARGET(self) -> int:
        """EDIT_TARGET property
        
        currently an edit target
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.EDIT_TARGET)
        _value = cast(int, value)
        return _value

    @property
    def edit_target(self) -> int:
        """EDIT_TARGET property
        
        currently an edit target
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        Note: both 'edit_target' and 'EDIT_TARGET' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.EDIT_TARGET)
        _value = cast(int, value)
        return _value

    @property
    def PROJECT_MASK(self) -> int:
        """PROJECT_MASK property
        
        object project mask
        
        Supported operations:
            getattr, setattr
        Datatype:
            64bit integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.PROJECT_MASK)
        _value = cast(int, value)
        return _value

    @PROJECT_MASK.setter
    def PROJECT_MASK(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.PROJECT_MASK, value)

    @property
    def project_mask(self) -> int:
        """PROJECT_MASK property
        
        object project mask
        
        Supported operations:
            getattr, setattr
        Datatype:
            64bit integer, scalar
        
        Note: both 'project_mask' and 'PROJECT_MASK' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.PROJECT_MASK)
        _value = cast(int, value)
        return _value

    @project_mask.setter
    def project_mask(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.PROJECT_MASK, value)

    @property
    def HANDLES_ENABLED(self) -> int:
        """Control the display and use of EnSight click and go handles for an object
        
        EnSight allows for direct interaction with many objects via click and go handles.
        The handles allow things like annotations and viewports to be moved or resized.
        They allow for the adjustment of values for clip planes and palette dynamic ranges.
        In some situations, allowing the user to directly adjust these values can be
        undesirable.  Setting this attribute to zero disables display of and interaction
        with click and go handles for the specific object instance.
        
        """
        value = self.getattr(self._session.ensight.objs.enums.HANDLES_ENABLED)
        _value = cast(int, value)
        return _value

    @HANDLES_ENABLED.setter
    def HANDLES_ENABLED(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.HANDLES_ENABLED, value)

    @property
    def handles_enabled(self) -> int:
        """Control the display and use of EnSight click and go handles for an object
        
        EnSight allows for direct interaction with many objects via click and go handles.
        The handles allow things like annotations and viewports to be moved or resized.
        They allow for the adjustment of values for clip planes and palette dynamic ranges.
        In some situations, allowing the user to directly adjust these values can be
        undesirable.  Setting this attribute to zero disables display of and interaction
        with click and go handles for the specific object instance.
        
        Note: both 'handles_enabled' and 'HANDLES_ENABLED' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.HANDLES_ENABLED)
        _value = cast(int, value)
        return _value

    @handles_enabled.setter
    def handles_enabled(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.HANDLES_ENABLED, value)

    @property
    def DESCRIPTION(self) -> str:
        """DESCRIPTION property
        
        description
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 256 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.DESCRIPTION)
        _value = cast(str, value)
        return _value

    @DESCRIPTION.setter
    def DESCRIPTION(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.DESCRIPTION, value)

    @property
    def description(self) -> str:
        """DESCRIPTION property
        
        description
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 256 characters maximum
        
        Note: both 'description' and 'DESCRIPTION' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.DESCRIPTION)
        _value = cast(str, value)
        return _value

    @description.setter
    def description(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.DESCRIPTION, value)

    @property
    def UNIQUENAME(self) -> str:
        """UNIQUENAME property
        
        unique name
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 256 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.UNIQUENAME)
        _value = cast(str, value)
        return _value

    @UNIQUENAME.setter
    def UNIQUENAME(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.UNIQUENAME, value)

    @property
    def uniquename(self) -> str:
        """UNIQUENAME property
        
        unique name
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 256 characters maximum
        
        Note: both 'uniquename' and 'UNIQUENAME' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.UNIQUENAME)
        _value = cast(str, value)
        return _value

    @uniquename.setter
    def uniquename(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.UNIQUENAME, value)

    @property
    def PATHNAME(self) -> str:
        """PATHNAME property
        
        full name
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 2048 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.PATHNAME)
        _value = cast(str, value)
        return _value

    @PATHNAME.setter
    def PATHNAME(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.PATHNAME, value)

    @property
    def pathname(self) -> str:
        """PATHNAME property
        
        full name
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 2048 characters maximum
        
        Note: both 'pathname' and 'PATHNAME' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.PATHNAME)
        _value = cast(str, value)
        return _value

    @pathname.setter
    def pathname(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.PATHNAME, value)

    @property
    def PARENT(self) -> ensobjlist:
        """PARENT property
        
        parent
        
        Supported operations:
            getattr
        Datatype:
            Object, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.PARENT)
        _value = cast(ensobjlist, value)
        return _value

    @property
    def parent(self) -> ensobjlist:
        """PARENT property
        
        parent
        
        Supported operations:
            getattr
        Datatype:
            Object, scalar
        
        Note: both 'parent' and 'PARENT' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.PARENT)
        _value = cast(ensobjlist, value)
        return _value

    @property
    def CHILDREN(self) -> ensobjlist:
        """CHILDREN property
        
        children
        
        Supported operations:
            getattr
        Datatype:
            Object, 0 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.CHILDREN)
        _value = cast(ensobjlist, value)
        return _value

    @property
    def children(self) -> ensobjlist:
        """CHILDREN property
        
        children
        
        Supported operations:
            getattr
        Datatype:
            Object, 0 element array
        
        Note: both 'children' and 'CHILDREN' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.CHILDREN)
        _value = cast(ensobjlist, value)
        return _value

    @property
    def SELECTIONS(self) -> int:
        """SELECTIONS property
        
        is selection
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.SELECTIONS)
        _value = cast(int, value)
        return _value

    @property
    def selections(self) -> int:
        """SELECTIONS property
        
        is selection
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        Note: both 'selections' and 'SELECTIONS' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.SELECTIONS)
        _value = cast(int, value)
        return _value

    @property
    def ROTATION(self) -> List[float]:
        """ROTATION property
        
        rotation
        
        Supported operations:
            getattr, setattr
        Datatype:
            Normalized Quaternion, 4 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ROTATION)
        _value = cast(List[float], value)
        return _value

    @ROTATION.setter
    def ROTATION(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.ROTATION, value)

    @property
    def rotation(self) -> List[float]:
        """ROTATION property
        
        rotation
        
        Supported operations:
            getattr, setattr
        Datatype:
            Normalized Quaternion, 4 element array
        
        Note: both 'rotation' and 'ROTATION' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ROTATION)
        _value = cast(List[float], value)
        return _value

    @rotation.setter
    def rotation(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.ROTATION, value)

    @property
    def TRANSLATION(self) -> List[float]:
        """TRANSLATION property
        
        translation
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.TRANSLATION)
        _value = cast(List[float], value)
        return _value

    @TRANSLATION.setter
    def TRANSLATION(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.TRANSLATION, value)

    @property
    def translation(self) -> List[float]:
        """TRANSLATION property
        
        translation
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        Note: both 'translation' and 'TRANSLATION' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.TRANSLATION)
        _value = cast(List[float], value)
        return _value

    @translation.setter
    def translation(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.TRANSLATION, value)

    @property
    def SCALE(self) -> List[float]:
        """SCALE property
        
        scale
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.SCALE)
        _value = cast(List[float], value)
        return _value

    @SCALE.setter
    def SCALE(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.SCALE, value)

    @property
    def scale(self) -> List[float]:
        """SCALE property
        
        scale
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        Note: both 'scale' and 'SCALE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.SCALE)
        _value = cast(List[float], value)
        return _value

    @scale.setter
    def scale(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.SCALE, value)

    @property
    def POLYGON_OFFSET(self) -> int:
        """POLYGON_OFFSET property
        
        use polygon offset
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.POLYGON_OFFSET)
        _value = cast(int, value)
        return _value

    @POLYGON_OFFSET.setter
    def POLYGON_OFFSET(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.POLYGON_OFFSET, value)

    @property
    def polygon_offset(self) -> int:
        """POLYGON_OFFSET property
        
        use polygon offset
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'polygon_offset' and 'POLYGON_OFFSET' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.POLYGON_OFFSET)
        _value = cast(int, value)
        return _value

    @polygon_offset.setter
    def polygon_offset(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.POLYGON_OFFSET, value)

    @property
    def OFFSET(self) -> List[float]:
        """OFFSET property
        
        offset
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.OFFSET)
        _value = cast(List[float], value)
        return _value

    @OFFSET.setter
    def OFFSET(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.OFFSET, value)

    @property
    def offset(self) -> List[float]:
        """OFFSET property
        
        offset
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        Note: both 'offset' and 'OFFSET' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.OFFSET)
        _value = cast(List[float], value)
        return _value

    @offset.setter
    def offset(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.OFFSET, value)



"""ens_annot_lgnd module

The ens_annot_lgnd module provides a proxy interface to EnSight ENS_ANNOT_LGND instances

"""
from ansys.pyensight.core.session import Session
from ansys.pyensight.core.ensobj import ENSOBJ
from ansys.pyensight.core import ensobjlist
from ansys.api.pyensight.ens_annot import ENS_ANNOT
from typing import Any, Dict, List, Type, Union, Optional, Tuple, TYPE_CHECKING, cast

if TYPE_CHECKING:
    from ansys.api.pyensight.ensight_api import ENS_VAR, ENS_ANNOT, ENS_PALETTE, ENS_PART, ENS_SOURCE, ENS_CASE, ENS_QUERY, ENS_GROUP, ENS_TOOL, ENS_TEXTURE, ENS_VPORT, ENS_PLOTTER, ENS_POLYLINE, ENS_FRAME, ENS_PROBE, ENS_FLIPBOOK, ENS_SCENE, ENS_LPART, ENS_STATE, ens_emitterobj

class ENS_ANNOT_LGND(ENS_ANNOT):
    """This class acts as a proxy for the EnSight Python class ensight.objs.ENS_ANNOT

    Args:
        \*args:
            Superclass (ENS_ANNOT) arguments
        \**kwargs:
            Superclass (ENS_ANNOT) keyword arguments

    """

    def __init__(self, *args, **kwargs) -> None:
        super().__init__(*args, **kwargs)
        self._update_attr_list(self._session, self._objid)

    @classmethod
    def _update_attr_list(cls, session: 'Session', id: int) -> None:
        if hasattr(cls, 'attr_list'):
            return
        cmd = session.remote_obj(id) + '.__ids__'
        cls.attr_list = session.cmd(cmd)

    @property
    def objid(self) -> int:  # noqa: N802
        """
        Return the EnSight object proxy ID (__OBJID__).
        """
        return self._objid

    def createannot(self, *args, **kwargs) -> Any:
        """Create a new annotation

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.createannot({arg_string})"
        return self._session.cmd(cmd)

    def attrgroupinfo(self, *args, **kwargs) -> Any:
        """Get information about GUI groups for this annot's attributes

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.attrgroupinfo({arg_string})"
        return self._session.cmd(cmd)

    @property
    def METADATA(self) -> Dict[Any, Any]:
        """METADATA property
        
        metadata
        
        Supported operations:
            getattr
        Datatype:
            CEI Metadata, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.METADATA)
        _value = cast(Dict[Any, Any], value)
        return _value

    @property
    def metadata(self) -> Dict[Any, Any]:
        """METADATA property
        
        metadata
        
        Supported operations:
            getattr
        Datatype:
            CEI Metadata, scalar
        
        Note: both 'metadata' and 'METADATA' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.METADATA)
        _value = cast(Dict[Any, Any], value)
        return _value

    @property
    def UUID(self) -> str:
        """UUID property
        
        universal unique id
        
        Supported operations:
            getattr
        Datatype:
            String, 37 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.UUID)
        _value = cast(str, value)
        return _value

    @property
    def uuid(self) -> str:
        """UUID property
        
        universal unique id
        
        Supported operations:
            getattr
        Datatype:
            String, 37 characters maximum
        
        Note: both 'uuid' and 'UUID' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.UUID)
        _value = cast(str, value)
        return _value

    @property
    def EDIT_TARGET(self) -> int:
        """EDIT_TARGET property
        
        currently an edit target
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.EDIT_TARGET)
        _value = cast(int, value)
        return _value

    @property
    def edit_target(self) -> int:
        """EDIT_TARGET property
        
        currently an edit target
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        Note: both 'edit_target' and 'EDIT_TARGET' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.EDIT_TARGET)
        _value = cast(int, value)
        return _value

    @property
    def PROJECT_MASK(self) -> int:
        """PROJECT_MASK property
        
        object project mask
        
        Supported operations:
            getattr, setattr
        Datatype:
            64bit integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.PROJECT_MASK)
        _value = cast(int, value)
        return _value

    @PROJECT_MASK.setter
    def PROJECT_MASK(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.PROJECT_MASK, value)

    @property
    def project_mask(self) -> int:
        """PROJECT_MASK property
        
        object project mask
        
        Supported operations:
            getattr, setattr
        Datatype:
            64bit integer, scalar
        
        Note: both 'project_mask' and 'PROJECT_MASK' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.PROJECT_MASK)
        _value = cast(int, value)
        return _value

    @project_mask.setter
    def project_mask(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.PROJECT_MASK, value)

    @property
    def HANDLES_ENABLED(self) -> int:
        """Control the display and use of EnSight click and go handles for an object
        
        EnSight allows for direct interaction with many objects via click and go handles.
        The handles allow things like annotations and viewports to be moved or resized.
        They allow for the adjustment of values for clip planes and palette dynamic ranges.
        In some situations, allowing the user to directly adjust these values can be
        undesirable.  Setting this attribute to zero disables display of and interaction
        with click and go handles for the specific object instance.
        
        """
        value = self.getattr(self._session.ensight.objs.enums.HANDLES_ENABLED)
        _value = cast(int, value)
        return _value

    @HANDLES_ENABLED.setter
    def HANDLES_ENABLED(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.HANDLES_ENABLED, value)

    @property
    def handles_enabled(self) -> int:
        """Control the display and use of EnSight click and go handles for an object
        
        EnSight allows for direct interaction with many objects via click and go handles.
        The handles allow things like annotations and viewports to be moved or resized.
        They allow for the adjustment of values for clip planes and palette dynamic ranges.
        In some situations, allowing the user to directly adjust these values can be
        undesirable.  Setting this attribute to zero disables display of and interaction
        with click and go handles for the specific object instance.
        
        Note: both 'handles_enabled' and 'HANDLES_ENABLED' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.HANDLES_ENABLED)
        _value = cast(int, value)
        return _value

    @handles_enabled.setter
    def handles_enabled(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.HANDLES_ENABLED, value)

    @property
    def ANNOTTYPE(self) -> int:
        """ANNOTTYPE property
        
        Type
        
        Supported operations:
            getattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.ANNO_TEXT - text annotation
            * ensight.objs.enums.ANNO_LINE - line annotation
            * ensight.objs.enums.ANNO_LOGO - logo annotation
            * ensight.objs.enums.ANNO_LGND - legend annotation
            * ensight.objs.enums.ANNO_ARROW - 3D arrow annotation
            * ensight.objs.enums.ANNO_DIAL - dial annotation
            * ensight.objs.enums.ANNO_GAUGE - gauge annotation
            * ensight.objs.enums.ANNO_SHAPE - 2D shape annotation
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ANNOTTYPE)
        _value = cast(int, value)
        return _value

    @property
    def annottype(self) -> int:
        """ANNOTTYPE property
        
        Type
        
        Supported operations:
            getattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.ANNO_TEXT - text annotation
            * ensight.objs.enums.ANNO_LINE - line annotation
            * ensight.objs.enums.ANNO_LOGO - logo annotation
            * ensight.objs.enums.ANNO_LGND - legend annotation
            * ensight.objs.enums.ANNO_ARROW - 3D arrow annotation
            * ensight.objs.enums.ANNO_DIAL - dial annotation
            * ensight.objs.enums.ANNO_GAUGE - gauge annotation
            * ensight.objs.enums.ANNO_SHAPE - 2D shape annotation
        
        Note: both 'annottype' and 'ANNOTTYPE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ANNOTTYPE)
        _value = cast(int, value)
        return _value

    @property
    def ANNOTINDEX(self) -> int:
        """ANNOTINDEX property
        
        annotation index
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ANNOTINDEX)
        _value = cast(int, value)
        return _value

    @property
    def annotindex(self) -> int:
        """ANNOTINDEX property
        
        annotation index
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        Note: both 'annotindex' and 'ANNOTINDEX' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ANNOTINDEX)
        _value = cast(int, value)
        return _value

    @property
    def SELECTED(self) -> int:
        """SELECTED property
        
        selected
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.SELECTED)
        _value = cast(int, value)
        return _value

    @SELECTED.setter
    def SELECTED(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SELECTED, value)

    @property
    def selected(self) -> int:
        """SELECTED property
        
        selected
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'selected' and 'SELECTED' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.SELECTED)
        _value = cast(int, value)
        return _value

    @selected.setter
    def selected(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SELECTED, value)

    @property
    def VARCOMP(self) -> List[Tuple['ENS_VAR', int]]:
        """VARCOMP property
        
        Legend variable
        
        Supported operations:
            getattr
        Datatype:
            ENS_VAR + component, 2 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.VARCOMP)
        _value = cast(List[Tuple['ENS_VAR', int]], value)
        return _value

    @property
    def varcomp(self) -> List[Tuple['ENS_VAR', int]]:
        """VARCOMP property
        
        Legend variable
        
        Supported operations:
            getattr
        Datatype:
            ENS_VAR + component, 2 element array
        
        Note: both 'varcomp' and 'VARCOMP' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.VARCOMP)
        _value = cast(List[Tuple['ENS_VAR', int]], value)
        return _value

    @property
    def DESCRIPTION(self) -> str:
        """DESCRIPTION property
        
        Description
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 1024 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.DESCRIPTION)
        _value = cast(str, value)
        return _value

    @DESCRIPTION.setter
    def DESCRIPTION(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.DESCRIPTION, value)

    @property
    def description(self) -> str:
        """DESCRIPTION property
        
        Description
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 1024 characters maximum
        
        Note: both 'description' and 'DESCRIPTION' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.DESCRIPTION)
        _value = cast(str, value)
        return _value

    @description.setter
    def description(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.DESCRIPTION, value)

    @property
    def VISIBLE(self) -> int:
        """VISIBLE property
        
        Visible
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.VISIBLE)
        _value = cast(int, value)
        return _value

    @VISIBLE.setter
    def VISIBLE(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.VISIBLE, value)

    @property
    def visible(self) -> int:
        """VISIBLE property
        
        Visible
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'visible' and 'VISIBLE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.VISIBLE)
        _value = cast(int, value)
        return _value

    @visible.setter
    def visible(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.VISIBLE, value)

    @property
    def SCALE(self) -> int:
        """SCALE property
        
        Scale
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.FNC_LINEAR - linear
            * ensight.objs.enums.FNC_QUAD - quadratic
            * ensight.objs.enums.FNC_LOG - logarithmic
        
        """
        value = self.getattr(self._session.ensight.objs.enums.SCALE)
        _value = cast(int, value)
        return _value

    @SCALE.setter
    def SCALE(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SCALE, value)

    @property
    def scale(self) -> int:
        """SCALE property
        
        Scale
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.FNC_LINEAR - linear
            * ensight.objs.enums.FNC_QUAD - quadratic
            * ensight.objs.enums.FNC_LOG - logarithmic
        
        Note: both 'scale' and 'SCALE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.SCALE)
        _value = cast(int, value)
        return _value

    @scale.setter
    def scale(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SCALE, value)

    @property
    def TYPE(self) -> int:
        """TYPE property
        
        Type
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.FNC_CONTIN - continuous
            * ensight.objs.enums.FNC_BAND - banded
            * ensight.objs.enums.FNC_CONST - constant
        
        """
        value = self.getattr(self._session.ensight.objs.enums.TYPE)
        _value = cast(int, value)
        return _value

    @TYPE.setter
    def TYPE(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.TYPE, value)

    @property
    def type(self) -> int:
        """TYPE property
        
        Type
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.FNC_CONTIN - continuous
            * ensight.objs.enums.FNC_BAND - banded
            * ensight.objs.enums.FNC_CONST - constant
        
        Note: both 'type' and 'TYPE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.TYPE)
        _value = cast(int, value)
        return _value

    @type.setter
    def type(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.TYPE, value)

    @property
    def RANGE(self) -> List[float]:
        """RANGE property
        
        Range
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 2 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.RANGE)
        _value = cast(List[float], value)
        return _value

    @RANGE.setter
    def RANGE(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.RANGE, value)

    @property
    def range(self) -> List[float]:
        """RANGE property
        
        Range
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 2 element array
        
        Note: both 'range' and 'RANGE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.RANGE)
        _value = cast(List[float], value)
        return _value

    @range.setter
    def range(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.RANGE, value)

    @property
    def RGB(self) -> List[float]:
        """RGB property
        
        Color
        
        Supported operations:
            getattr, setattr
        Datatype:
            Color RGB, 3 element array
        Range:
            [0.0, 1.0]
        
        """
        value = self.getattr(self._session.ensight.objs.enums.RGB)
        _value = cast(List[float], value)
        return _value

    @RGB.setter
    def RGB(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.RGB, value)

    @property
    def rgb(self) -> List[float]:
        """RGB property
        
        Color
        
        Supported operations:
            getattr, setattr
        Datatype:
            Color RGB, 3 element array
        Range:
            [0.0, 1.0]
        
        Note: both 'rgb' and 'RGB' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.RGB)
        _value = cast(List[float], value)
        return _value

    @rgb.setter
    def rgb(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.RGB, value)

    @property
    def RELATIVETO(self) -> int:
        """RELATIVETO property
        
        Relative to
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.TS_VIEWPORT_RELATIVE - specific_viewport
            * ensight.objs.enums.TS_SCREEN_RELATIVE - entire_view
        
        """
        value = self.getattr(self._session.ensight.objs.enums.RELATIVETO)
        _value = cast(int, value)
        return _value

    @RELATIVETO.setter
    def RELATIVETO(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.RELATIVETO, value)

    @property
    def relativeto(self) -> int:
        """RELATIVETO property
        
        Relative to
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.TS_VIEWPORT_RELATIVE - specific_viewport
            * ensight.objs.enums.TS_SCREEN_RELATIVE - entire_view
        
        Note: both 'relativeto' and 'RELATIVETO' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.RELATIVETO)
        _value = cast(int, value)
        return _value

    @relativeto.setter
    def relativeto(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.RELATIVETO, value)

    @property
    def RELATIVEVIEWPORT(self) -> int:
        """RELATIVEVIEWPORT property
        
        Relative viewport
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        Range:
            [0, inf]
        
        """
        value = self.getattr(self._session.ensight.objs.enums.RELATIVEVIEWPORT)
        _value = cast(int, value)
        return _value

    @RELATIVEVIEWPORT.setter
    def RELATIVEVIEWPORT(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.RELATIVEVIEWPORT, value)

    @property
    def relativeviewport(self) -> int:
        """RELATIVEVIEWPORT property
        
        Relative viewport
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        Range:
            [0, inf]
        
        Note: both 'relativeviewport' and 'RELATIVEVIEWPORT' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.RELATIVEVIEWPORT)
        _value = cast(int, value)
        return _value

    @relativeviewport.setter
    def relativeviewport(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.RELATIVEVIEWPORT, value)

    @property
    def SHADOWOFFSET(self) -> int:
        """SHADOWOFFSET property
        
        Shadow offset
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        Range:
            [0, 10]
        
        """
        value = self.getattr(self._session.ensight.objs.enums.SHADOWOFFSET)
        _value = cast(int, value)
        return _value

    @SHADOWOFFSET.setter
    def SHADOWOFFSET(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SHADOWOFFSET, value)

    @property
    def shadowoffset(self) -> int:
        """SHADOWOFFSET property
        
        Shadow offset
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        Range:
            [0, 10]
        
        Note: both 'shadowoffset' and 'SHADOWOFFSET' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.SHADOWOFFSET)
        _value = cast(int, value)
        return _value

    @shadowoffset.setter
    def shadowoffset(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SHADOWOFFSET, value)

    @property
    def SHADOWINTENSITY(self) -> float:
        """SHADOWINTENSITY property
        
        Shadow intensity
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        Range:
            [0.0, 1.0]
        
        """
        value = self.getattr(self._session.ensight.objs.enums.SHADOWINTENSITY)
        _value = cast(float, value)
        return _value

    @SHADOWINTENSITY.setter
    def SHADOWINTENSITY(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.SHADOWINTENSITY, value)

    @property
    def shadowintensity(self) -> float:
        """SHADOWINTENSITY property
        
        Shadow intensity
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        Range:
            [0.0, 1.0]
        
        Note: both 'shadowintensity' and 'SHADOWINTENSITY' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.SHADOWINTENSITY)
        _value = cast(float, value)
        return _value

    @shadowintensity.setter
    def shadowintensity(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.SHADOWINTENSITY, value)

    @property
    def LOCATIONX(self) -> float:
        """LOCATIONX property
        
        X
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        Range:
            [0.0, 1.0]
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LOCATIONX)
        _value = cast(float, value)
        return _value

    @LOCATIONX.setter
    def LOCATIONX(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.LOCATIONX, value)

    @property
    def locationx(self) -> float:
        """LOCATIONX property
        
        X
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        Range:
            [0.0, 1.0]
        
        Note: both 'locationx' and 'LOCATIONX' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LOCATIONX)
        _value = cast(float, value)
        return _value

    @locationx.setter
    def locationx(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.LOCATIONX, value)

    @property
    def LOCATIONY(self) -> float:
        """LOCATIONY property
        
        Y
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        Range:
            [0.0, 1.0]
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LOCATIONY)
        _value = cast(float, value)
        return _value

    @LOCATIONY.setter
    def LOCATIONY(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.LOCATIONY, value)

    @property
    def locationy(self) -> float:
        """LOCATIONY property
        
        Y
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        Range:
            [0.0, 1.0]
        
        Note: both 'locationy' and 'LOCATIONY' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LOCATIONY)
        _value = cast(float, value)
        return _value

    @locationy.setter
    def locationy(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.LOCATIONY, value)

    @property
    def WIDTH(self) -> float:
        """WIDTH property
        
        Width
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        Range:
            [0.0, 1.0]
        
        """
        value = self.getattr(self._session.ensight.objs.enums.WIDTH)
        _value = cast(float, value)
        return _value

    @WIDTH.setter
    def WIDTH(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.WIDTH, value)

    @property
    def width(self) -> float:
        """WIDTH property
        
        Width
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        Range:
            [0.0, 1.0]
        
        Note: both 'width' and 'WIDTH' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.WIDTH)
        _value = cast(float, value)
        return _value

    @width.setter
    def width(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.WIDTH, value)

    @property
    def ORIENTATION(self) -> int:
        """ORIENTATION property
        
        Orientation
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.FALSE - vertical
            * ensight.objs.enums.TRUE - horizontal
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ORIENTATION)
        _value = cast(int, value)
        return _value

    @ORIENTATION.setter
    def ORIENTATION(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.ORIENTATION, value)

    @property
    def orientation(self) -> int:
        """ORIENTATION property
        
        Orientation
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.FALSE - vertical
            * ensight.objs.enums.TRUE - horizontal
        
        Note: both 'orientation' and 'ORIENTATION' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ORIENTATION)
        _value = cast(int, value)
        return _value

    @orientation.setter
    def orientation(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.ORIENTATION, value)

    @property
    def HEIGHT(self) -> float:
        """HEIGHT property
        
        Height
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        Range:
            [0.0, 1.0]
        
        """
        value = self.getattr(self._session.ensight.objs.enums.HEIGHT)
        _value = cast(float, value)
        return _value

    @HEIGHT.setter
    def HEIGHT(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.HEIGHT, value)

    @property
    def height(self) -> float:
        """HEIGHT property
        
        Height
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        Range:
            [0.0, 1.0]
        
        Note: both 'height' and 'HEIGHT' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.HEIGHT)
        _value = cast(float, value)
        return _value

    @height.setter
    def height(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.HEIGHT, value)

    @property
    def TEXTSIZE(self) -> int:
        """TEXTSIZE property
        
        Size
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        Range:
            [1, 100]
        
        """
        value = self.getattr(self._session.ensight.objs.enums.TEXTSIZE)
        _value = cast(int, value)
        return _value

    @TEXTSIZE.setter
    def TEXTSIZE(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.TEXTSIZE, value)

    @property
    def textsize(self) -> int:
        """TEXTSIZE property
        
        Size
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        Range:
            [1, 100]
        
        Note: both 'textsize' and 'TEXTSIZE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.TEXTSIZE)
        _value = cast(int, value)
        return _value

    @textsize.setter
    def textsize(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.TEXTSIZE, value)

    @property
    def TEXTRGB(self) -> List[float]:
        """TEXTRGB property
        
        Color
        
        Supported operations:
            getattr, setattr
        Datatype:
            Color RGB, 3 element array
        Range:
            [0.0, 1.0]
        
        """
        value = self.getattr(self._session.ensight.objs.enums.TEXTRGB)
        _value = cast(List[float], value)
        return _value

    @TEXTRGB.setter
    def TEXTRGB(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.TEXTRGB, value)

    @property
    def textrgb(self) -> List[float]:
        """TEXTRGB property
        
        Color
        
        Supported operations:
            getattr, setattr
        Datatype:
            Color RGB, 3 element array
        Range:
            [0.0, 1.0]
        
        Note: both 'textrgb' and 'TEXTRGB' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.TEXTRGB)
        _value = cast(List[float], value)
        return _value

    @textrgb.setter
    def textrgb(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.TEXTRGB, value)

    @property
    def TEXTPOSITION(self) -> int:
        """TEXTPOSITION property
        
        Location
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.LEGEND_LEFT - left
            * ensight.objs.enums.LEGEND_RIGHT - right
            * ensight.objs.enums.LEGEND_LEFT - bottom
            * ensight.objs.enums.LEGEND_RIGHT - top
            * ensight.objs.enums.LEGEND_TXT_VISOFF - none
        
        """
        value = self.getattr(self._session.ensight.objs.enums.TEXTPOSITION)
        _value = cast(int, value)
        return _value

    @TEXTPOSITION.setter
    def TEXTPOSITION(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.TEXTPOSITION, value)

    @property
    def textposition(self) -> int:
        """TEXTPOSITION property
        
        Location
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.LEGEND_LEFT - left
            * ensight.objs.enums.LEGEND_RIGHT - right
            * ensight.objs.enums.LEGEND_LEFT - bottom
            * ensight.objs.enums.LEGEND_RIGHT - top
            * ensight.objs.enums.LEGEND_TXT_VISOFF - none
        
        Note: both 'textposition' and 'TEXTPOSITION' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.TEXTPOSITION)
        _value = cast(int, value)
        return _value

    @textposition.setter
    def textposition(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.TEXTPOSITION, value)

    @property
    def TEXTTYPE(self) -> int:
        """TEXTTYPE property
        
        Text type
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.LEGEND_TITLE_VISOFF - off
            * ensight.objs.enums.LEGEND_TITLE_VISOFF - normal
            * ensight.objs.enums.LEGEND_TITLE_VISOFF - graphics_font
        
        """
        value = self.getattr(self._session.ensight.objs.enums.TEXTTYPE)
        _value = cast(int, value)
        return _value

    @TEXTTYPE.setter
    def TEXTTYPE(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.TEXTTYPE, value)

    @property
    def texttype(self) -> int:
        """TEXTTYPE property
        
        Text type
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.LEGEND_TITLE_VISOFF - off
            * ensight.objs.enums.LEGEND_TITLE_VISOFF - normal
            * ensight.objs.enums.LEGEND_TITLE_VISOFF - graphics_font
        
        Note: both 'texttype' and 'TEXTTYPE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.TEXTTYPE)
        _value = cast(int, value)
        return _value

    @texttype.setter
    def texttype(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.TEXTTYPE, value)

    @property
    def FORMAT(self) -> str:
        """FORMAT property
        
        Format
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 1024 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.FORMAT)
        _value = cast(str, value)
        return _value

    @FORMAT.setter
    def FORMAT(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.FORMAT, value)

    @property
    def format(self) -> str:
        """FORMAT property
        
        Format
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 1024 characters maximum
        
        Note: both 'format' and 'FORMAT' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.FORMAT)
        _value = cast(str, value)
        return _value

    @format.setter
    def format(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.FORMAT, value)

    @property
    def TITLELOCATION(self) -> int:
        """TITLELOCATION property
        
        Title location
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.LEGEND_TITLE_TOP - above
            * ensight.objs.enums.LEGEND_TITLE_BOTTOM - below
            * ensight.objs.enums.LEGEND_TITLE_VISOFF - none
        
        """
        value = self.getattr(self._session.ensight.objs.enums.TITLELOCATION)
        _value = cast(int, value)
        return _value

    @TITLELOCATION.setter
    def TITLELOCATION(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.TITLELOCATION, value)

    @property
    def titlelocation(self) -> int:
        """TITLELOCATION property
        
        Title location
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.LEGEND_TITLE_TOP - above
            * ensight.objs.enums.LEGEND_TITLE_BOTTOM - below
            * ensight.objs.enums.LEGEND_TITLE_VISOFF - none
        
        Note: both 'titlelocation' and 'TITLELOCATION' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.TITLELOCATION)
        _value = cast(int, value)
        return _value

    @titlelocation.setter
    def titlelocation(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.TITLELOCATION, value)

    @property
    def SHOWMINMAXMARKER(self) -> int:
        """SHOWMINMAXMARKER property
        
        Show minmax marker
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.SHOWMINMAXMARKER)
        _value = cast(int, value)
        return _value

    @SHOWMINMAXMARKER.setter
    def SHOWMINMAXMARKER(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SHOWMINMAXMARKER, value)

    @property
    def showminmaxmarker(self) -> int:
        """SHOWMINMAXMARKER property
        
        Show minmax marker
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'showminmaxmarker' and 'SHOWMINMAXMARKER' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.SHOWMINMAXMARKER)
        _value = cast(int, value)
        return _value

    @showminmaxmarker.setter
    def showminmaxmarker(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SHOWMINMAXMARKER, value)

    @property
    def LEGENDTYPE(self) -> int:
        """LEGENDTYPE property
        
        Legend type
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.LEGEND_CONT - continuous
            * ensight.objs.enums.LEGEND_DISC - discrete
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LEGENDTYPE)
        _value = cast(int, value)
        return _value

    @LEGENDTYPE.setter
    def LEGENDTYPE(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LEGENDTYPE, value)

    @property
    def legendtype(self) -> int:
        """LEGENDTYPE property
        
        Legend type
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.LEGEND_CONT - continuous
            * ensight.objs.enums.LEGEND_DISC - discrete
        
        Note: both 'legendtype' and 'LEGENDTYPE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LEGENDTYPE)
        _value = cast(int, value)
        return _value

    @legendtype.setter
    def legendtype(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LEGENDTYPE, value)

    @property
    def SHOWBACKGROUND(self) -> int:
        """SHOWBACKGROUND property
        
        Show background
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.SHOWBACKGROUND)
        _value = cast(int, value)
        return _value

    @SHOWBACKGROUND.setter
    def SHOWBACKGROUND(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SHOWBACKGROUND, value)

    @property
    def showbackground(self) -> int:
        """SHOWBACKGROUND property
        
        Show background
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'showbackground' and 'SHOWBACKGROUND' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.SHOWBACKGROUND)
        _value = cast(int, value)
        return _value

    @showbackground.setter
    def showbackground(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SHOWBACKGROUND, value)

    @property
    def SPECIFYLABELCOUNT(self) -> int:
        """SPECIFYLABELCOUNT property
        
        Specify label count
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.SPECIFYLABELCOUNT)
        _value = cast(int, value)
        return _value

    @SPECIFYLABELCOUNT.setter
    def SPECIFYLABELCOUNT(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SPECIFYLABELCOUNT, value)

    @property
    def specifylabelcount(self) -> int:
        """SPECIFYLABELCOUNT property
        
        Specify label count
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'specifylabelcount' and 'SPECIFYLABELCOUNT' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.SPECIFYLABELCOUNT)
        _value = cast(int, value)
        return _value

    @specifylabelcount.setter
    def specifylabelcount(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SPECIFYLABELCOUNT, value)

    @property
    def LABELCOUNT(self) -> int:
        """LABELCOUNT property
        
        Label count
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        Range:
            [2, 50]
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LABELCOUNT)
        _value = cast(int, value)
        return _value

    @LABELCOUNT.setter
    def LABELCOUNT(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LABELCOUNT, value)

    @property
    def labelcount(self) -> int:
        """LABELCOUNT property
        
        Label count
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        Range:
            [2, 50]
        
        Note: both 'labelcount' and 'LABELCOUNT' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LABELCOUNT)
        _value = cast(int, value)
        return _value

    @labelcount.setter
    def labelcount(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LABELCOUNT, value)

    @property
    def NUMOFLEVELS(self) -> int:
        """NUMOFLEVELS property
        
        Number of levels
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        Range:
            [2, 21]
        
        """
        value = self.getattr(self._session.ensight.objs.enums.NUMOFLEVELS)
        _value = cast(int, value)
        return _value

    @NUMOFLEVELS.setter
    def NUMOFLEVELS(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.NUMOFLEVELS, value)

    @property
    def numoflevels(self) -> int:
        """NUMOFLEVELS property
        
        Number of levels
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        Range:
            [2, 21]
        
        Note: both 'numoflevels' and 'NUMOFLEVELS' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.NUMOFLEVELS)
        _value = cast(int, value)
        return _value

    @numoflevels.setter
    def numoflevels(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.NUMOFLEVELS, value)

    @property
    def LIMITFRINGES(self) -> int:
        """LIMITFRINGES property
        
        Outside range display
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.FNC_NOLIMIT - no
            * ensight.objs.enums.FNC_LIMCOL - by_part_color
            * ensight.objs.enums.FNC_LIMVIS - by_invisible
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LIMITFRINGES)
        _value = cast(int, value)
        return _value

    @LIMITFRINGES.setter
    def LIMITFRINGES(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LIMITFRINGES, value)

    @property
    def limitfringes(self) -> int:
        """LIMITFRINGES property
        
        Outside range display
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.FNC_NOLIMIT - no
            * ensight.objs.enums.FNC_LIMCOL - by_part_color
            * ensight.objs.enums.FNC_LIMVIS - by_invisible
        
        Note: both 'limitfringes' and 'LIMITFRINGES' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LIMITFRINGES)
        _value = cast(int, value)
        return _value

    @limitfringes.setter
    def limitfringes(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LIMITFRINGES, value)

    @property
    def DISPLAYUNDEFINED(self) -> int:
        """DISPLAYUNDEFINED property
        
        Undefined value display
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.CVF_PALETTE_UNDEFINED_BY_PART_COLOR - by_part_color
            * ensight.objs.enums.CVF_PALETTE_UNDEFINED_BY_INVISIBLE - by_invisible
            * ensight.objs.enums.CVF_PALETTE_UNDEFINED_AS_ZERO_VALUE - as_zero_value
            * ensight.objs.enums.CVF_PALETTE_UNDEFINED_BY_UNDEF_COLOR - by_specified_color
        
        """
        value = self.getattr(self._session.ensight.objs.enums.DISPLAYUNDEFINED)
        _value = cast(int, value)
        return _value

    @DISPLAYUNDEFINED.setter
    def DISPLAYUNDEFINED(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.DISPLAYUNDEFINED, value)

    @property
    def displayundefined(self) -> int:
        """DISPLAYUNDEFINED property
        
        Undefined value display
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.CVF_PALETTE_UNDEFINED_BY_PART_COLOR - by_part_color
            * ensight.objs.enums.CVF_PALETTE_UNDEFINED_BY_INVISIBLE - by_invisible
            * ensight.objs.enums.CVF_PALETTE_UNDEFINED_AS_ZERO_VALUE - as_zero_value
            * ensight.objs.enums.CVF_PALETTE_UNDEFINED_BY_UNDEF_COLOR - by_specified_color
        
        Note: both 'displayundefined' and 'DISPLAYUNDEFINED' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.DISPLAYUNDEFINED)
        _value = cast(int, value)
        return _value

    @displayundefined.setter
    def displayundefined(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.DISPLAYUNDEFINED, value)

    @property
    def UNDEFINEDCOLOR(self) -> List[float]:
        """UNDEFINEDCOLOR property
        
        Undefined color
        
        Supported operations:
            getattr, setattr
        Datatype:
            Color RGB, 3 element array
        Range:
            [0.0, 1.0]
        
        """
        value = self.getattr(self._session.ensight.objs.enums.UNDEFINEDCOLOR)
        _value = cast(List[float], value)
        return _value

    @UNDEFINEDCOLOR.setter
    def UNDEFINEDCOLOR(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.UNDEFINEDCOLOR, value)

    @property
    def undefinedcolor(self) -> List[float]:
        """UNDEFINEDCOLOR property
        
        Undefined color
        
        Supported operations:
            getattr, setattr
        Datatype:
            Color RGB, 3 element array
        Range:
            [0.0, 1.0]
        
        Note: both 'undefinedcolor' and 'UNDEFINEDCOLOR' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.UNDEFINEDCOLOR)
        _value = cast(List[float], value)
        return _value

    @undefinedcolor.setter
    def undefinedcolor(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.UNDEFINEDCOLOR, value)



import os

def ensight_api_test_assests():
    """Read ensight_api_test_assets.txt and return it as string.

    Returns
    -------
    str
        The file contents as string.
    """
    dir = os.path.dirname(__file__)
    assets_file_name = os.path.join(dir, "assets", "ensight_api_test_assets.txt")
    with open(assets_file_name, "r") as file:
        file_str = file.read()
    return file_str



"""ens_lpart module

The ens_lpart module provides a proxy interface to EnSight ENS_LPART instances

"""
from ansys.pyensight.core.session import Session
from ansys.pyensight.core.ensobj import ENSOBJ
from ansys.pyensight.core import ensobjlist
from typing import Any, Dict, List, Type, Union, Optional, Tuple, TYPE_CHECKING, cast

if TYPE_CHECKING:
    from ansys.api.pyensight.ensight_api import ENS_VAR, ENS_ANNOT, ENS_PALETTE, ENS_PART, ENS_SOURCE, ENS_CASE, ENS_QUERY, ENS_GROUP, ENS_TOOL, ENS_TEXTURE, ENS_VPORT, ENS_PLOTTER, ENS_POLYLINE, ENS_FRAME, ENS_PROBE, ENS_FLIPBOOK, ENS_SCENE, ENS_STATE, ens_emitterobj

class ENS_LPART(ENSOBJ):
    """This class acts as a proxy for the EnSight Python class ensight.objs.ENS_LPART

    Args:
        \*args:
            Superclass (ENSOBJ) arguments
        \**kwargs:
            Superclass (ENSOBJ) keyword arguments

    """

    def __init__(self, *args, **kwargs) -> None:
        super().__init__(*args, **kwargs)
        self._update_attr_list(self._session, self._objid)

    @classmethod
    def _update_attr_list(cls, session: 'Session', id: int) -> None:
        if hasattr(cls, 'attr_list'):
            return
        cmd = session.remote_obj(id) + '.__ids__'
        cls.attr_list = session.cmd(cmd)

    @property
    def objid(self) -> int:  # noqa: N802
        """
        Return the EnSight object proxy ID (__OBJID__).
        """
        return self._objid

    def attrgroupinfo(self, *args, **kwargs) -> Any:
        """Get information about GUI groups for object attributes

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.attrgroupinfo({arg_string})"
        return self._session.cmd(cmd)

    def load(self, *args, **kwargs) -> Any:
        """Load the part

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.load({arg_string})"
        return self._session.cmd(cmd)

    @property
    def METADATA(self) -> Dict[Any, Any]:
        """METADATA property
        
        metadata
        
        Supported operations:
            getattr
        Datatype:
            CEI Metadata, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.METADATA)
        _value = cast(Dict[Any, Any], value)
        return _value

    @property
    def metadata(self) -> Dict[Any, Any]:
        """METADATA property
        
        metadata
        
        Supported operations:
            getattr
        Datatype:
            CEI Metadata, scalar
        
        Note: both 'metadata' and 'METADATA' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.METADATA)
        _value = cast(Dict[Any, Any], value)
        return _value

    @property
    def UUID(self) -> str:
        """UUID property
        
        universal unique id
        
        Supported operations:
            getattr
        Datatype:
            String, 37 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.UUID)
        _value = cast(str, value)
        return _value

    @property
    def uuid(self) -> str:
        """UUID property
        
        universal unique id
        
        Supported operations:
            getattr
        Datatype:
            String, 37 characters maximum
        
        Note: both 'uuid' and 'UUID' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.UUID)
        _value = cast(str, value)
        return _value

    @property
    def EDIT_TARGET(self) -> int:
        """EDIT_TARGET property
        
        currently an edit target
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.EDIT_TARGET)
        _value = cast(int, value)
        return _value

    @property
    def edit_target(self) -> int:
        """EDIT_TARGET property
        
        currently an edit target
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        Note: both 'edit_target' and 'EDIT_TARGET' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.EDIT_TARGET)
        _value = cast(int, value)
        return _value

    @property
    def PROJECT_MASK(self) -> int:
        """PROJECT_MASK property
        
        object project mask
        
        Supported operations:
            getattr, setattr
        Datatype:
            64bit integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.PROJECT_MASK)
        _value = cast(int, value)
        return _value

    @PROJECT_MASK.setter
    def PROJECT_MASK(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.PROJECT_MASK, value)

    @property
    def project_mask(self) -> int:
        """PROJECT_MASK property
        
        object project mask
        
        Supported operations:
            getattr, setattr
        Datatype:
            64bit integer, scalar
        
        Note: both 'project_mask' and 'PROJECT_MASK' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.PROJECT_MASK)
        _value = cast(int, value)
        return _value

    @project_mask.setter
    def project_mask(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.PROJECT_MASK, value)

    @property
    def HANDLES_ENABLED(self) -> int:
        """Control the display and use of EnSight click and go handles for an object
        
        EnSight allows for direct interaction with many objects via click and go handles.
        The handles allow things like annotations and viewports to be moved or resized.
        They allow for the adjustment of values for clip planes and palette dynamic ranges.
        In some situations, allowing the user to directly adjust these values can be
        undesirable.  Setting this attribute to zero disables display of and interaction
        with click and go handles for the specific object instance.
        
        """
        value = self.getattr(self._session.ensight.objs.enums.HANDLES_ENABLED)
        _value = cast(int, value)
        return _value

    @HANDLES_ENABLED.setter
    def HANDLES_ENABLED(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.HANDLES_ENABLED, value)

    @property
    def handles_enabled(self) -> int:
        """Control the display and use of EnSight click and go handles for an object
        
        EnSight allows for direct interaction with many objects via click and go handles.
        The handles allow things like annotations and viewports to be moved or resized.
        They allow for the adjustment of values for clip planes and palette dynamic ranges.
        In some situations, allowing the user to directly adjust these values can be
        undesirable.  Setting this attribute to zero disables display of and interaction
        with click and go handles for the specific object instance.
        
        Note: both 'handles_enabled' and 'HANDLES_ENABLED' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.HANDLES_ENABLED)
        _value = cast(int, value)
        return _value

    @handles_enabled.setter
    def handles_enabled(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.HANDLES_ENABLED, value)

    @property
    def DTA_BLOCK(self) -> int:
        """DTA_BLOCK property
        
        Block
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.DTA_BLOCK)
        _value = cast(int, value)
        return _value

    @property
    def dta_block(self) -> int:
        """DTA_BLOCK property
        
        Block
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        Note: both 'dta_block' and 'DTA_BLOCK' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.DTA_BLOCK)
        _value = cast(int, value)
        return _value

    @property
    def ENS_KIND(self) -> str:
        """ENS_KIND property
        
        Kind
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 4096 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ENS_KIND)
        _value = cast(str, value)
        return _value

    @ENS_KIND.setter
    def ENS_KIND(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.ENS_KIND, value)

    @property
    def ens_kind(self) -> str:
        """ENS_KIND property
        
        Kind
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 4096 characters maximum
        
        Note: both 'ens_kind' and 'ENS_KIND' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ENS_KIND)
        _value = cast(str, value)
        return _value

    @ens_kind.setter
    def ens_kind(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.ENS_KIND, value)

    @property
    def ENS_DETAILS(self) -> str:
        """ENS_DETAILS property
        
        Details
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 4096 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ENS_DETAILS)
        _value = cast(str, value)
        return _value

    @ENS_DETAILS.setter
    def ENS_DETAILS(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.ENS_DETAILS, value)

    @property
    def ens_details(self) -> str:
        """ENS_DETAILS property
        
        Details
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 4096 characters maximum
        
        Note: both 'ens_details' and 'ENS_DETAILS' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ENS_DETAILS)
        _value = cast(str, value)
        return _value

    @ens_details.setter
    def ens_details(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.ENS_DETAILS, value)

    @property
    def ENS_MATERIAL(self) -> str:
        """ENS_MATERIAL property
        
        Material
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 4096 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ENS_MATERIAL)
        _value = cast(str, value)
        return _value

    @ENS_MATERIAL.setter
    def ENS_MATERIAL(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.ENS_MATERIAL, value)

    @property
    def ens_material(self) -> str:
        """ENS_MATERIAL property
        
        Material
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 4096 characters maximum
        
        Note: both 'ens_material' and 'ENS_MATERIAL' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ENS_MATERIAL)
        _value = cast(str, value)
        return _value

    @ens_material.setter
    def ens_material(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.ENS_MATERIAL, value)

    @property
    def ENS_PARENT_PART(self) -> str:
        """ENS_PARENT_PART property
        
        Parent
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 4096 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ENS_PARENT_PART)
        _value = cast(str, value)
        return _value

    @ENS_PARENT_PART.setter
    def ENS_PARENT_PART(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.ENS_PARENT_PART, value)

    @property
    def ens_parent_part(self) -> str:
        """ENS_PARENT_PART property
        
        Parent
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 4096 characters maximum
        
        Note: both 'ens_parent_part' and 'ENS_PARENT_PART' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ENS_PARENT_PART)
        _value = cast(str, value)
        return _value

    @ens_parent_part.setter
    def ens_parent_part(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.ENS_PARENT_PART, value)

    @property
    def ENS_SYMMETRY_AXIS(self) -> str:
        """ENS_SYMMETRY_AXIS property
        
        Sym Axis
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 4096 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ENS_SYMMETRY_AXIS)
        _value = cast(str, value)
        return _value

    @ENS_SYMMETRY_AXIS.setter
    def ENS_SYMMETRY_AXIS(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.ENS_SYMMETRY_AXIS, value)

    @property
    def ens_symmetry_axis(self) -> str:
        """ENS_SYMMETRY_AXIS property
        
        Sym Axis
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 4096 characters maximum
        
        Note: both 'ens_symmetry_axis' and 'ENS_SYMMETRY_AXIS' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ENS_SYMMETRY_AXIS)
        _value = cast(str, value)
        return _value

    @ens_symmetry_axis.setter
    def ens_symmetry_axis(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.ENS_SYMMETRY_AXIS, value)

    @property
    def ENS_SYMMETRY_COUNT(self) -> int:
        """ENS_SYMMETRY_COUNT property
        
        Sym Count
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ENS_SYMMETRY_COUNT)
        _value = cast(int, value)
        return _value

    @ENS_SYMMETRY_COUNT.setter
    def ENS_SYMMETRY_COUNT(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.ENS_SYMMETRY_COUNT, value)

    @property
    def ens_symmetry_count(self) -> int:
        """ENS_SYMMETRY_COUNT property
        
        Sym Count
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        
        Note: both 'ens_symmetry_count' and 'ENS_SYMMETRY_COUNT' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ENS_SYMMETRY_COUNT)
        _value = cast(int, value)
        return _value

    @ens_symmetry_count.setter
    def ens_symmetry_count(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.ENS_SYMMETRY_COUNT, value)

    @property
    def ENS_TURBO_STAGE(self) -> str:
        """ENS_TURBO_STAGE property
        
        Turbo Type
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 4096 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ENS_TURBO_STAGE)
        _value = cast(str, value)
        return _value

    @ENS_TURBO_STAGE.setter
    def ENS_TURBO_STAGE(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.ENS_TURBO_STAGE, value)

    @property
    def ens_turbo_stage(self) -> str:
        """ENS_TURBO_STAGE property
        
        Turbo Type
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 4096 characters maximum
        
        Note: both 'ens_turbo_stage' and 'ENS_TURBO_STAGE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ENS_TURBO_STAGE)
        _value = cast(str, value)
        return _value

    @ens_turbo_stage.setter
    def ens_turbo_stage(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.ENS_TURBO_STAGE, value)

    @property
    def ENS_TURBO_VIEW(self) -> str:
        """ENS_TURBO_VIEW property
        
        Turbo Kind
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 4096 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ENS_TURBO_VIEW)
        _value = cast(str, value)
        return _value

    @ENS_TURBO_VIEW.setter
    def ENS_TURBO_VIEW(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.ENS_TURBO_VIEW, value)

    @property
    def ens_turbo_view(self) -> str:
        """ENS_TURBO_VIEW property
        
        Turbo Kind
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 4096 characters maximum
        
        Note: both 'ens_turbo_view' and 'ENS_TURBO_VIEW' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ENS_TURBO_VIEW)
        _value = cast(str, value)
        return _value

    @ens_turbo_view.setter
    def ens_turbo_view(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.ENS_TURBO_VIEW, value)

    @property
    def ENS_TURBO_VDIM(self) -> str:
        """ENS_TURBO_VDIM property
        
        Turbo Vports
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 4096 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ENS_TURBO_VDIM)
        _value = cast(str, value)
        return _value

    @ENS_TURBO_VDIM.setter
    def ENS_TURBO_VDIM(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.ENS_TURBO_VDIM, value)

    @property
    def ens_turbo_vdim(self) -> str:
        """ENS_TURBO_VDIM property
        
        Turbo Vports
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 4096 characters maximum
        
        Note: both 'ens_turbo_vdim' and 'ENS_TURBO_VDIM' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ENS_TURBO_VDIM)
        _value = cast(str, value)
        return _value

    @ens_turbo_vdim.setter
    def ens_turbo_vdim(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.ENS_TURBO_VDIM, value)

    @property
    def DESCRIPTION(self) -> str:
        """DESCRIPTION property
        
        description
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 256 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.DESCRIPTION)
        _value = cast(str, value)
        return _value

    @DESCRIPTION.setter
    def DESCRIPTION(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.DESCRIPTION, value)

    @property
    def description(self) -> str:
        """DESCRIPTION property
        
        description
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 256 characters maximum
        
        Note: both 'description' and 'DESCRIPTION' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.DESCRIPTION)
        _value = cast(str, value)
        return _value

    @description.setter
    def description(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.DESCRIPTION, value)

    @property
    def PATHNAME(self) -> str:
        """PATHNAME property
        
        full name
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 2048 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.PATHNAME)
        _value = cast(str, value)
        return _value

    @PATHNAME.setter
    def PATHNAME(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.PATHNAME, value)

    @property
    def pathname(self) -> str:
        """PATHNAME property
        
        full name
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 2048 characters maximum
        
        Note: both 'pathname' and 'PATHNAME' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.PATHNAME)
        _value = cast(str, value)
        return _value

    @pathname.setter
    def pathname(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.PATHNAME, value)

    @property
    def PARENT(self) -> ensobjlist:
        """PARENT property
        
        parent
        
        Supported operations:
            getattr
        Datatype:
            Object, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.PARENT)
        _value = cast(ensobjlist, value)
        return _value

    @property
    def parent(self) -> ensobjlist:
        """PARENT property
        
        parent
        
        Supported operations:
            getattr
        Datatype:
            Object, scalar
        
        Note: both 'parent' and 'PARENT' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.PARENT)
        _value = cast(ensobjlist, value)
        return _value

    @property
    def MESHTYPE(self) -> int:
        """MESHTYPE property
        
        meshtype
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.MESHTYPE)
        _value = cast(int, value)
        return _value

    @property
    def meshtype(self) -> int:
        """MESHTYPE property
        
        meshtype
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        Note: both 'meshtype' and 'MESHTYPE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.MESHTYPE)
        _value = cast(int, value)
        return _value

    @property
    def DIMENSIONS(self) -> List[int]:
        """DIMENSIONS property
        
        structured dimensions
        
        Supported operations:
            getattr
        Datatype:
            Integer, 6 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.DIMENSIONS)
        _value = cast(List[int], value)
        return _value

    @property
    def dimensions(self) -> List[int]:
        """DIMENSIONS property
        
        structured dimensions
        
        Supported operations:
            getattr
        Datatype:
            Integer, 6 element array
        
        Note: both 'dimensions' and 'DIMENSIONS' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.DIMENSIONS)
        _value = cast(List[int], value)
        return _value

    @property
    def ELEMCOUNT(self) -> List[int]:
        """ELEMCOUNT property
        
        element count
        
        Supported operations:
            getattr
        Datatype:
            Integer, 40 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ELEMCOUNT)
        _value = cast(List[int], value)
        return _value

    @property
    def elemcount(self) -> List[int]:
        """ELEMCOUNT property
        
        element count
        
        Supported operations:
            getattr
        Datatype:
            Integer, 40 element array
        
        Note: both 'elemcount' and 'ELEMCOUNT' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ELEMCOUNT)
        _value = cast(List[int], value)
        return _value

    @property
    def PARTNUMELE(self) -> Dict[Any, Any]:
        """PARTNUMELE property
        
        number of server elements
        
        Supported operations:
            getattr
        Datatype:
            Dictionary, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.PARTNUMELE)
        _value = cast(Dict[Any, Any], value)
        return _value

    @property
    def partnumele(self) -> Dict[Any, Any]:
        """PARTNUMELE property
        
        number of server elements
        
        Supported operations:
            getattr
        Datatype:
            Dictionary, scalar
        
        Note: both 'partnumele' and 'PARTNUMELE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.PARTNUMELE)
        _value = cast(Dict[Any, Any], value)
        return _value

    @property
    def DELTA(self) -> List[int]:
        """DELTA property
        
        load delta
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, 3 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.DELTA)
        _value = cast(List[int], value)
        return _value

    @DELTA.setter
    def DELTA(self, value: List[int]) -> None:
        self.setattr(self._session.ensight.objs.enums.DELTA, value)

    @property
    def delta(self) -> List[int]:
        """DELTA property
        
        load delta
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, 3 element array
        
        Note: both 'delta' and 'DELTA' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.DELTA)
        _value = cast(List[int], value)
        return _value

    @delta.setter
    def delta(self, value: List[int]) -> None:
        self.setattr(self._session.ensight.objs.enums.DELTA, value)

    @property
    def NODEMIN(self) -> List[int]:
        """NODEMIN property
        
        minimum node numbers
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, 3 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.NODEMIN)
        _value = cast(List[int], value)
        return _value

    @NODEMIN.setter
    def NODEMIN(self, value: List[int]) -> None:
        self.setattr(self._session.ensight.objs.enums.NODEMIN, value)

    @property
    def nodemin(self) -> List[int]:
        """NODEMIN property
        
        minimum node numbers
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, 3 element array
        
        Note: both 'nodemin' and 'NODEMIN' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.NODEMIN)
        _value = cast(List[int], value)
        return _value

    @nodemin.setter
    def nodemin(self, value: List[int]) -> None:
        self.setattr(self._session.ensight.objs.enums.NODEMIN, value)

    @property
    def NODEMAX(self) -> List[int]:
        """NODEMAX property
        
        maximum node numbers
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, 3 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.NODEMAX)
        _value = cast(List[int], value)
        return _value

    @NODEMAX.setter
    def NODEMAX(self, value: List[int]) -> None:
        self.setattr(self._session.ensight.objs.enums.NODEMAX, value)

    @property
    def nodemax(self) -> List[int]:
        """NODEMAX property
        
        maximum node numbers
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, 3 element array
        
        Note: both 'nodemax' and 'NODEMAX' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.NODEMAX)
        _value = cast(List[int], value)
        return _value

    @nodemax.setter
    def nodemax(self, value: List[int]) -> None:
        self.setattr(self._session.ensight.objs.enums.NODEMAX, value)

    @property
    def NODESTEP(self) -> List[int]:
        """NODESTEP property
        
        step factor
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, 3 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.NODESTEP)
        _value = cast(List[int], value)
        return _value

    @NODESTEP.setter
    def NODESTEP(self, value: List[int]) -> None:
        self.setattr(self._session.ensight.objs.enums.NODESTEP, value)

    @property
    def nodestep(self) -> List[int]:
        """NODESTEP property
        
        step factor
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, 3 element array
        
        Note: both 'nodestep' and 'NODESTEP' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.NODESTEP)
        _value = cast(List[int], value)
        return _value

    @nodestep.setter
    def nodestep(self, value: List[int]) -> None:
        self.setattr(self._session.ensight.objs.enums.NODESTEP, value)

    @property
    def DOMAIN(self) -> int:
        """DOMAIN property
        
        domain
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.ZONES_DEF - Default Zones
            * ensight.objs.enums.ZONES_EXT - External Zones
            * ensight.objs.enums.ZONES_INT - Internal Zones
            * ensight.objs.enums.ZONES_BOTH - All Zones
        
        """
        value = self.getattr(self._session.ensight.objs.enums.DOMAIN)
        _value = cast(int, value)
        return _value

    @DOMAIN.setter
    def DOMAIN(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.DOMAIN, value)

    @property
    def domain(self) -> int:
        """DOMAIN property
        
        domain
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.ZONES_DEF - Default Zones
            * ensight.objs.enums.ZONES_EXT - External Zones
            * ensight.objs.enums.ZONES_INT - Internal Zones
            * ensight.objs.enums.ZONES_BOTH - All Zones
        
        Note: both 'domain' and 'DOMAIN' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.DOMAIN)
        _value = cast(int, value)
        return _value

    @domain.setter
    def domain(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.DOMAIN, value)

    @property
    def INDEX(self) -> int:
        """INDEX property
        
        index
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.INDEX)
        _value = cast(int, value)
        return _value

    @property
    def index(self) -> int:
        """INDEX property
        
        index
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        Note: both 'index' and 'INDEX' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.INDEX)
        _value = cast(int, value)
        return _value

    @property
    def FLOW3DINFO(self) -> object:
        """FLOW3DINFO property
        
        Flow3D dataset information
        
        Supported operations:
            getattr
        Datatype:
            EnSight Object, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.FLOW3DINFO)
        _value = cast(object, value)
        return _value

    @property
    def flow3dinfo(self) -> object:
        """FLOW3DINFO property
        
        Flow3D dataset information
        
        Supported operations:
            getattr
        Datatype:
            EnSight Object, scalar
        
        Note: both 'flow3dinfo' and 'FLOW3DINFO' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.FLOW3DINFO)
        _value = cast(object, value)
        return _value
